@@ -133,13 +133,14 @@ newMriImageMetadataFromDicomMetadata <- function (dicom)
             slices <- NULL
         else if (rows == dataColumns && columns == dataRows)
         {
-            flag(OL$Warning, "Data matrix is transposed relative to acquisition matrix")
+            flag(OL$Info, "Data matrix is transposed relative to acquisition matrix")
             rows <- dataRows
             columns <- dataColumns
             slices <- NULL
         }
-        else
+        else if (identical(dicom$getTagValue(0x0008,0x0070), "SIEMENS"))
         {
+            # Siemens mosaic format
             slices <- (dataRows/rows) * (dataColumns/columns)
             if (slices != floor(slices))
             {
@@ -149,6 +150,13 @@ newMriImageMetadataFromDicomMetadata <- function (dicom)
                 columns <- dataColumns
             }
         }
+        else
+        {
+            # Image upsampled or downsampled after acquisition, e.g. by zero filling
+            slices <- NULL
+            rows <- dataRows
+            columns <- dataColumns
+        }
     }
     
     if (is.null(slices))
@@ -201,8 +209,6 @@ newMriImageFromDicomMetadata <- function (metadata, flipY = TRUE)
     fileMetadata <- metadata
     if (fileMetadata$getTagValue(0x0008, 0x0060) != "MR")
         output(OL$Error, "DICOM file does not contain MR image data")
-    if (!equivalent(fileMetadata$getTagValue(0x0020,0x0037), c(1,0,0,0,1,0)))
-        flag(OL$Warning, "DICOM file does not use LPS orientation slices - results may be unreliable")
     imageMetadata <- newMriImageMetadataFromDicomMetadata(fileMetadata)
     
     datatype <- imageMetadata$getDataType()
@@ -486,7 +492,7 @@ newMriImageFromDicomDirectory <- function (dicomDir, readDiffusionParams = FALSE
 
     if (!volumePerDicomFile && nSlices>1 && length(firstLocs)==2 && diff(firstLocs)<0)
     {
-        flag(OL$Warning, "Slice location decreases between consecutive images - inverting slice order")
+        output(OL$Info, "Slice location decreases between consecutive images - inverting slice order")
         indices <- alist(x=, y=, z=, t=)
         indices[[throughSliceDirection]] <- nSlices:1
         data <- do.call("[", c(list(data),indices,list(drop=FALSE)))
