@@ -203,8 +203,33 @@ splitAndConvertString <- function (string, split = "", mode = "character", error
         return (values)
 }
 
-getWithDefault <- function (name, defaultValue, mode = NULL, errorIfMissing = FALSE, errorIfInvalid = FALSE)
+getWithDefault <- function (name, defaultValue, mode = NULL, errorIfMissing = FALSE, errorIfInvalid = FALSE, validValues = NULL)
 {
+    reportInvalid <- function ()
+    {
+        level <- ifelse(errorIfInvalid, OL$Error, OL$Warning)
+        message <- paste("The configuration variable \"", name, "\" does not have a suitable and unambiguous value", ifelse(errorIfInvalid,""," - using default"), sep="")
+        output(level, message)
+    }
+    
+    matchAgainstValidValues <- function (currentValue)
+    {
+        if (is.null(validValues))
+            return (currentValue)
+        else if (isTRUE(mode == "character"))
+            loc <- pmatch(tolower(currentValue), tolower(validValues), nomatch=0)
+        else
+            loc <- match(currentValue, validValues, nomatch=0)
+        
+        if (loc != 0)
+            return (validValues[loc])
+        else
+        {
+            reportInvalid()
+            return (defaultValue)
+        }
+    }
+    
     if (is.null(mode) && !is.null(defaultValue))
         mode <- mode(defaultValue)
     
@@ -215,23 +240,21 @@ getWithDefault <- function (name, defaultValue, mode = NULL, errorIfMissing = FA
         else
             return (defaultValue)
     }
-    else if (is.null(mode) || mode == "NULL")
-        return (get(name))
     else
     {
         value <- get(name)
-        if (!isValidAs(value, mode))
+        if (is.null(mode) || mode == "NULL")
+            return (matchAgainstValidValues(value))
+        else if (!isValidAs(value, mode))
         {
-            if (errorIfInvalid)
-                output(OL$Error, "The configuration variable \"", name, "\" does not have a suitable value")
-            else
-            {
-                output(OL$Warning, "The configuration variable \"", name, "\" does not have a suitable value - ignoring")
-                return (defaultValue)
-            }
+            reportInvalid()
+            return (defaultValue)
         }
         else
-            return (as(value, mode))
+        {
+            value <- as(value, mode)
+            return (matchAgainstValidValues(value))
+        }
     }
 }
 
